@@ -125,6 +125,14 @@
 #include "eas_report.h"
 #include <string.h>
 
+// for mp3 decoding
+#define MINIMP3_IMPLEMENTATION
+#define MINIMP3_ONLY_MP3
+#include "minimp3.h"
+
+// for a-law/u-law decoding
+#include "pcm_aulaw.h"
+
 //2 we should replace log10() function with fixed point routine in ConvertSampleRate()
 /* lint is choking on the ARM math.h file, so we declare the log10 function here */
 extern double log10(double x);
@@ -231,6 +239,7 @@ typedef struct
     EAS_U32 loopStart;
     EAS_U32 loopLength;
     EAS_U32 sampleRate;
+    EAS_U16 fmtTag;
     EAS_U16 bitsPerSample;
     EAS_I16 fineTune;
     EAS_U8  unityNote;
@@ -422,6 +431,7 @@ static EAS_RESULT Parse_wave (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
 static EAS_RESULT Parse_wsmp (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, S_WSMP_DATA *p);
 static EAS_RESULT Parse_fmt (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, S_WSMP_DATA *p);
 static EAS_RESULT Parse_data (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_I32 size, S_WSMP_DATA *p, EAS_SAMPLE *pSample, EAS_U32 sampleLen);
+static EAS_RESULT Parse_mp3_data (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_I32 size, EAS_SAMPLE *pSample, EAS_I32 *sampleLen);
 static EAS_RESULT Parse_lins(SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_I32 size);
 static EAS_RESULT Parse_ins (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_I32 size);
 static EAS_RESULT Parse_insh (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_U32 *pRgnCount, EAS_U32 *pLocale);
@@ -508,7 +518,7 @@ EAS_RESULT DLSParser (EAS_HW_DATA_HANDLE hwInstData, EAS_FILE_HANDLE fileHandle,
         return result;
     if (temp != CHUNK_DLS)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "Expected DLS chunk, got %08lx\n", temp); */ }
+        EAS_Report(_EAS_SEVERITY_ERROR, "Expected DLS chunk, got %08lx\n", temp);
         return EAS_ERROR_FILE_FORMAT;
     }
 
@@ -559,21 +569,21 @@ EAS_RESULT DLSParser (EAS_HW_DATA_HANDLE hwInstData, EAS_FILE_HANDLE fileHandle,
     /* must have a lins chunk */
     if (linsSize == 0)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "No lins chunk found"); */ }
+        EAS_Report(_EAS_SEVERITY_ERROR, "No lins chunk found");
         return EAS_ERROR_UNRECOGNIZED_FORMAT;
     }
 
     /* must have a wvpl chunk */
     if (wvplSize == 0)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "No wvpl chunk found"); */ }
+        EAS_Report(_EAS_SEVERITY_ERROR, "No wvpl chunk found");
         return EAS_ERROR_UNRECOGNIZED_FORMAT;
     }
 
     /* must have a ptbl chunk */
     if ((ptblSize == 0) || (ptblSize > (EAS_I32) (DLS_MAX_WAVE_COUNT * sizeof(POOLCUE) + sizeof(POOLTABLE))))
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "No ptbl chunk found"); */ }
+        EAS_Report(_EAS_SEVERITY_ERROR, "No ptbl chunk found");
         return EAS_ERROR_UNRECOGNIZED_FORMAT;
     }
 
@@ -584,7 +594,7 @@ EAS_RESULT DLSParser (EAS_HW_DATA_HANDLE hwInstData, EAS_FILE_HANDLE fileHandle,
     /* limit check  */
     if ((dls.waveCount == 0) || (dls.waveCount > DLS_MAX_WAVE_COUNT))
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "DLS file contains invalid #waves [%u]\n", dls.waveCount); */ }
+        EAS_Report(_EAS_SEVERITY_ERROR, "DLS file contains invalid #waves [%u]\n", dls.waveCount);
         return EAS_ERROR_FILE_FORMAT;
     }
 
@@ -592,7 +602,7 @@ EAS_RESULT DLSParser (EAS_HW_DATA_HANDLE hwInstData, EAS_FILE_HANDLE fileHandle,
     dls.wsmpData = EAS_HWMalloc(dls.hwInstData, (EAS_I32) (sizeof(S_WSMP_DATA) * dls.waveCount));
     if (dls.wsmpData == NULL)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "EAS_HWMalloc for wsmp data failed\n"); */ }
+        EAS_Report(_EAS_SEVERITY_ERROR, "EAS_HWMalloc for wsmp data failed\n");
         return EAS_ERROR_MALLOC_FAILED;
     }
     EAS_HWMemSet(dls.wsmpData, 0, (EAS_I32) (sizeof(S_WSMP_DATA) * dls.waveCount));
@@ -605,7 +615,7 @@ EAS_RESULT DLSParser (EAS_HW_DATA_HANDLE hwInstData, EAS_FILE_HANDLE fileHandle,
         /* limit check  */
         if ((dls.regionCount == 0) || (dls.regionCount > DLS_MAX_REGION_COUNT))
         {
-            { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "DLS file contains invalid #regions [%u]\n", dls.regionCount); */ }
+            EAS_Report(_EAS_SEVERITY_ERROR, "DLS file contains invalid #regions [%u]\n", dls.regionCount);
             EAS_HWFree(dls.hwInstData, dls.wsmpData);
             return EAS_ERROR_FILE_FORMAT;
         }
@@ -613,7 +623,7 @@ EAS_RESULT DLSParser (EAS_HW_DATA_HANDLE hwInstData, EAS_FILE_HANDLE fileHandle,
         /* limit check  */
         if ((dls.artCount == 0) || (dls.artCount > DLS_MAX_ART_COUNT))
         {
-            { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "DLS file contains invalid #articulations [%u]\n", dls.regionCount); */ }
+            EAS_Report(_EAS_SEVERITY_ERROR, "DLS file contains invalid #articulations [%u]\n", dls.artCount);
             EAS_HWFree(dls.hwInstData, dls.wsmpData);
             return EAS_ERROR_FILE_FORMAT;
         }
@@ -621,7 +631,7 @@ EAS_RESULT DLSParser (EAS_HW_DATA_HANDLE hwInstData, EAS_FILE_HANDLE fileHandle,
         /* limit check  */
         if ((dls.instCount == 0) || (dls.instCount > DLS_MAX_INST_COUNT))
         {
-            { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "DLS file contains invalid #instruments [%u]\n", dls.instCount); */ }
+            EAS_Report(_EAS_SEVERITY_ERROR, "DLS file contains invalid #instruments [%u]\n", dls.instCount);
             EAS_HWFree(dls.hwInstData, dls.wsmpData);
             return EAS_ERROR_FILE_FORMAT;
         }
@@ -651,7 +661,7 @@ EAS_RESULT DLSParser (EAS_HW_DATA_HANDLE hwInstData, EAS_FILE_HANDLE fileHandle,
         dls.pDLS = EAS_HWMalloc(dls.hwInstData, size);
         if (dls.pDLS == NULL)
         {
-            { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "EAS_HWMalloc failed for DLS memory allocation size %ld\n", size); */ }
+            EAS_Report(_EAS_SEVERITY_ERROR, "EAS_HWMalloc failed for DLS memory allocation size %ld\n", size);
             EAS_HWFree(dls.hwInstData, dls.wsmpData);
             return EAS_ERROR_MALLOC_FAILED;
         }
@@ -795,6 +805,7 @@ static EAS_RESULT NextChunk (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 *pPos, EAS
         return result;
 
     if (*pSize < 0) {
+        EAS_Report(_EAS_SEVERITY_ERROR, "Invalid DLS chunk size\n");
         ALOGE("b/37093318");
         return EAS_ERROR_FILE_FORMAT;
     }
@@ -880,7 +891,7 @@ static EAS_RESULT Parse_ptbl (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
             return result;
         if (temp > (EAS_U32) wtblSize)
         {
-            { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "Ptbl offset exceeds size of wtbl\n"); */ }
+            EAS_Report(_EAS_SEVERITY_ERROR, "Ptbl offset exceeds size of wtbl\n");
             EAS_HWCloseFile(pDLSData->hwInstData, tempFile);
             return EAS_ERROR_FILE_FORMAT;
         }
@@ -936,7 +947,7 @@ static EAS_RESULT Parse_wave (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
     /* make sure it is a wave chunk */
     if (temp != CHUNK_WAVE)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "Offset in ptbl does not point to wave chunk\n"); */ }
+        EAS_Report(_EAS_SEVERITY_ERROR, "Offset in ptbl does not point to wave chunk\n");
         return EAS_ERROR_FILE_FORMAT;
     }
 
@@ -994,14 +1005,14 @@ static EAS_RESULT Parse_wave (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
     /* must have a fmt chunk */
     if (!fmtPos)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "DLS wave chunk has no fmt chunk\n"); */ }
+        EAS_Report(_EAS_SEVERITY_ERROR, "DLS wave chunk has no fmt chunk\n");
         return EAS_ERROR_UNRECOGNIZED_FORMAT;
     }
 
     /* must have a data chunk */
     if (!dataPos)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "DLS wave chunk has no data chunk\n"); */ }
+        EAS_Report(_EAS_SEVERITY_ERROR, "DLS wave chunk has no data chunk\n");
         return EAS_ERROR_UNRECOGNIZED_FORMAT;
     }
 
@@ -1035,8 +1046,6 @@ static EAS_RESULT Parse_wave (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
         else
             /*lint -e{704} use shift for performance */
             size = dataSize >> 1;
-        if (p->loopLength)
-            size++;
     }
 
     else
@@ -1046,10 +1055,19 @@ static EAS_RESULT Parse_wave (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
         else
             /*lint -e{703} use shift for performance */
             size = dataSize << 1;
-        if (p->loopLength)
-            size += 2;
     }
 
+    switch (p->fmtTag)
+    {
+        case WAVE_FORMAT_MPEGLAYER3:
+            if ((result = Parse_mp3_data(pDLSData, dataPos, dataSize, NULL, &size)) != EAS_SUCCESS)
+                return result;
+            break;
+    }
+
+    if (p->loopLength)
+        size += bitDepth / 8;
+
     /* for first pass, add size to wave pool size and return */
     if (pDLSData->pDLS == NULL)
     {
@@ -1064,7 +1082,7 @@ static EAS_RESULT Parse_wave (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
     pDLSData->wavePoolOffset += (EAS_U32) size;
     if (pDLSData->wavePoolOffset > pDLSData->wavePoolSize)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "Wave pool exceeded allocation\n"); */ }
+        EAS_Report(_EAS_SEVERITY_ERROR, "Wave pool exceeded allocation\n");
         return EAS_ERROR_SOUND_LIBRARY;
     }
 
@@ -1111,7 +1129,7 @@ static EAS_RESULT Parse_wsmp (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, S_WS
     else
     {
         p->unityNote = 60;
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_WARNING, "Invalid unity note [%u] in DLS wsmp ignored, set to 60\n", wtemp); */ }
+        EAS_Report(_EAS_SEVERITY_WARNING, "Invalid unity note [%u] in DLS wsmp ignored, set to 60\n", wtemp);
     }
 
     /* get fine tune */
@@ -1123,7 +1141,7 @@ static EAS_RESULT Parse_wsmp (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, S_WS
         return result;
     if (p->gain > 0)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_WARNING, "Positive gain [%ld] in DLS wsmp ignored, set to 0dB\n", p->gain); */ }
+        EAS_Report(_EAS_SEVERITY_DETAIL, "Positive gain [%ld] in DLS wsmp ignored, set to 0dB\n", p->gain);
         p->gain = 0;
     }
 
@@ -1140,7 +1158,7 @@ static EAS_RESULT Parse_wsmp (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, S_WS
     {
 
         if (ltemp > 1)
-            { /* dpp: EAS_ReportEx(_EAS_SEVERITY_WARNING, "DLS sample with %lu loops, ignoring extra loops\n", ltemp); */ }
+            EAS_Report(_EAS_SEVERITY_WARNING, "DLS sample with %lu loops, ignoring extra loops\n", ltemp);
 
         /* skip ahead to loop data */
         if ((result = EAS_HWFileSeek(pDLSData->hwInstData, pDLSData->fileHandle, pos + (EAS_I32) cbSize)) != EAS_SUCCESS)
@@ -1201,10 +1219,17 @@ static EAS_RESULT Parse_fmt (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, S_WSM
     /* get format tag */
     if ((result = EAS_HWGetWord(pDLSData->hwInstData, pDLSData->fileHandle, &wtemp, EAS_FALSE)) != EAS_SUCCESS)
         return result;
-    if (wtemp != WAVE_FORMAT_PCM)
+    switch(wtemp)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "Unsupported DLS sample format %04x\n", wtemp); */ }
-        return EAS_ERROR_UNRECOGNIZED_FORMAT;
+        case WAVE_FORMAT_PCM:
+        case WAVE_FORMAT_ALAW:
+        case WAVE_FORMAT_MULAW:
+        case WAVE_FORMAT_MPEGLAYER3:
+            p->fmtTag = wtemp;
+            break;
+        default:
+            EAS_Report(_EAS_SEVERITY_ERROR, "Unsupported DLS sample format %04x\n", wtemp);
+            return EAS_ERROR_UNRECOGNIZED_FORMAT;
     }
 
     /* get number of channels */
@@ -1212,7 +1237,7 @@ static EAS_RESULT Parse_fmt (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, S_WSM
         return result;
     if (wtemp != 1)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "No support for DLS multi-channel samples\n"); */ }
+        EAS_Report(_EAS_SEVERITY_ERROR, "No support for DLS multi-channel samples\n");
         return EAS_ERROR_UNRECOGNIZED_FORMAT;
     }
 
@@ -1234,7 +1259,7 @@ static EAS_RESULT Parse_fmt (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, S_WSM
 
     if ((p->bitsPerSample != 8) && (p->bitsPerSample != 16))
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "Unsupported DLS bits-per-sample %d\n", p->bitsPerSample); */ }
+        EAS_Report(_EAS_SEVERITY_ERROR, "Unsupported DLS bits-per-sample %d\n", p->bitsPerSample);
         return EAS_ERROR_UNRECOGNIZED_FORMAT;
     }
 
@@ -1268,6 +1293,9 @@ static EAS_RESULT Parse_data (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
     EAS_I32 i;
     EAS_I8 *p;
 
+    if (pWsmp->fmtTag != WAVE_FORMAT_PCM)
+        return EAS_ERROR_UNRECOGNIZED_FORMAT;
+
     /* seek to start of chunk */
     if ((result = EAS_HWFileSeek(pDLSData->hwInstData, pDLSData->fileHandle, pos)) != EAS_SUCCESS)
         return result;
@@ -1317,7 +1345,7 @@ static EAS_RESULT Parse_data (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
     if (pWsmp->loopLength)
     {
         if (sampleLen < sizeof(EAS_SAMPLE)
-            || (pWsmp->loopStart + pWsmp->loopLength) * sizeof(EAS_SAMPLE) > sampleLen - sizeof(EAS_SAMPLE))
+            || (pWsmp->loopStart + pWsmp->loopLength) * sizeof(EAS_SAMPLE) > sampleLen)
         {
             return EAS_FAILURE;
         }
@@ -1336,6 +1364,13 @@ static EAS_RESULT Parse_data (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
     EAS_I32 i;
     EAS_I16 *p;
 
+    if (pWsmp->fmtTag == WAVE_FORMAT_MPEGLAYER3)
+    {
+        if ((result = Parse_mp3_data(pDLSData, pos, size, pSample, NULL)) != EAS_SUCCESS)
+            return result;
+        goto handle_loop;
+    }
+
     /* seek to start of chunk */
     if ((result = EAS_HWFileSeek(pDLSData->hwInstData, pDLSData->fileHandle, pos)) != EAS_SUCCESS)
         return result;
@@ -1358,14 +1393,32 @@ static EAS_RESULT Parse_data (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
         }
         else
         {
-            for(i=0; i<count; i++)
+            switch(pWsmp->fmtTag)
             {
-                *p++ = (short)((convBuf[i] ^ 0x80) << 8);
+                case WAVE_FORMAT_ALAW:
+                    for(i=0; i<count; i++)
+                    {
+                        *p++ = alaw2linear(convBuf[i]);
+                    }
+                    break;
+                case WAVE_FORMAT_MULAW:
+                    for(i=0; i<count; i++)
+                    {
+                        *p++ = ulaw2linear(convBuf[i]);
+                    }
+                    break;
+                case WAVE_FORMAT_PCM:
+                    for(i=0; i<count; i++)
+                    {
+                        *p++ = (short)((convBuf[i] ^ 0x80) << 8);
+                    }
+                    break;
             }
         }
 
     }
 
+handle_loop:
     /* for looped samples, copy the last sample to the end */
     if (pWsmp->loopLength)
     {
@@ -1374,7 +1427,8 @@ static EAS_RESULT Parse_data (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
             return EAS_SUCCESS;
         }
         if (sampleLen < sizeof(EAS_SAMPLE)
-            || (pWsmp->loopStart + pWsmp->loopLength) * sizeof(EAS_SAMPLE) > sampleLen - sizeof(EAS_SAMPLE)) {
+            || (pWsmp->loopStart + pWsmp->loopLength) * sizeof(EAS_SAMPLE) > sampleLen)
+        {
             return EAS_FAILURE;
         }
 
@@ -1387,6 +1441,92 @@ static EAS_RESULT Parse_data (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
 #error "Must specifiy _8_BIT_SAMPLES or _16_BIT_SAMPLES"
 #endif
 
+/*----------------------------------------------------------------------------
+ * Parse_mp3_data ()
+ *----------------------------------------------------------------------------
+ * Purpose:
+ * Decoding mp3 data or return sample length for wave pool memory allocation
+ *
+ * Inputs:
+ * pEASData - pointer for accessing mp3 data in file
+ * pos - position of mp3 data
+ * size - size of mp3 data
+ * pSample - pointer to store decoded sample data
+ * sampleLen - pointer to store sample length (for wave pool memory allocation)
+ *
+ * Outputs:
+ * EAS_RESULT
+ *
+ *----------------------------------------------------------------------------
+*/
+static EAS_RESULT Parse_mp3_data (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_I32 size, EAS_SAMPLE *pSample, EAS_I32 *sampleLen)
+{
+    EAS_RESULT result;
+    EAS_U8 convBuf[MAX_FREE_FORMAT_FRAME_SIZE];
+
+    EAS_SAMPLE *p;
+    EAS_I32 readCount;
+    EAS_I32 bytesInBuffer;
+    EAS_I32 sampleSize = 0;
+    EAS_I32 remainingSize = 0;
+
+    mp3dec_t mp3d;
+    mp3dec_frame_info_t info;
+
+    /* check if pcm types are equal */
+    if (sizeof(*p) != sizeof(mp3d_sample_t))
+        return EAS_ERROR_INVALID_PCM_TYPE;
+
+    /* seek to start of chunk */
+    if ((result = EAS_HWFileSeek(pDLSData->hwInstData, pDLSData->fileHandle, pos)) != EAS_SUCCESS)
+        return result;
+
+    p = pSample;
+
+    /* init mp3dec */
+    mp3dec_init(&mp3d);
+
+    while (size > 0)
+    {
+        if (remainingSize)
+        {
+            if (remainingSize < 0)
+                return EAS_BUFFER_SIZE_MISMATCH;
+            /* put the remaining data at the end into the beginning of the buffer */
+            EAS_HWMemCpy(convBuf, convBuf + bytesInBuffer - remainingSize, remainingSize);
+        }
+        readCount = (size < sizeof(convBuf) ? size : sizeof(convBuf));
+        readCount -= remainingSize;
+
+        if ((result = EAS_HWReadFile(pDLSData->hwInstData, pDLSData->fileHandle, convBuf + remainingSize, readCount, &readCount)) != EAS_SUCCESS)
+            return result;
+        remainingSize += readCount;
+        bytesInBuffer = remainingSize;
+
+        int samples = mp3dec_decode_frame(&mp3d, convBuf, remainingSize, p, &info);
+        if (samples == 0)
+            return EAS_FAILURE;
+
+        if (p != NULL)
+            p += samples * info.channels;
+        else
+            sampleSize += samples * info.channels;
+
+        size -= info.frame_bytes;
+        remainingSize -= info.frame_bytes;
+    }
+
+    /* i think there are no garbage in mp3 data */
+    if (size)
+        return EAS_ERROR_DATA_INCONSISTENCY;
+
+    /* for first pass, add size to wave pool size and return */
+    if (pSample == NULL)
+        *sampleLen = sampleSize * sizeof(mp3d_sample_t);
+
+    return EAS_SUCCESS;
+}
+
 /*----------------------------------------------------------------------------
  * Parse_lins ()
  *----------------------------------------------------------------------------
@@ -1522,14 +1662,14 @@ static EAS_RESULT Parse_ins (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_I
     /* must have an lrgn to be useful */
     if (!lrgnPos)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "DLS ins chunk has no lrgn chunk\n"); */ }
+        EAS_Report(_EAS_SEVERITY_ERROR, "DLS ins chunk has no lrgn chunk\n");
         return EAS_ERROR_UNRECOGNIZED_FORMAT;
     }
 
     /* must have an insh to be useful */
     if (!inshPos)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "DLS ins chunk has no insh chunk\n"); */ }
+        EAS_Report(_EAS_SEVERITY_ERROR, "DLS ins chunk has no insh chunk\n");
         return EAS_ERROR_UNRECOGNIZED_FORMAT;
     }
 
@@ -1612,7 +1752,7 @@ static EAS_RESULT Parse_insh (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
     /* verify the parameters are valid */
     if (bank & 0x7fff8080)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_WARNING, "DLS bank number is out of range: %08lx\n", bank); */ }
+        EAS_Report(_EAS_SEVERITY_WARNING, "DLS bank number is out of range: %08lx\n", bank);
     }
     if (bank & 0x80000000u)
     {
@@ -1627,7 +1767,7 @@ static EAS_RESULT Parse_insh (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
     }
     if (program > 127)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_WARNING, "DLS program number is out of range: %08lx\n", program); */ }
+        EAS_Report(_EAS_SEVERITY_WARNING, "DLS program number is out of range: %08lx\n", program);
         program &= 0x7f;
     }
 
@@ -1677,7 +1817,7 @@ static EAS_RESULT Parse_lrgn (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
         {
             if (regionCount == numRegions)
             {
-                { /* dpp: EAS_ReportEx(_EAS_SEVERITY_WARNING, "DLS region count exceeded cRegions value in insh, extra region ignored\n"); */ }
+                EAS_Report(_EAS_SEVERITY_WARNING, "DLS region count exceeded cRegions value in insh, extra region ignored\n");
                 return EAS_SUCCESS;
             }
             /* if second pass, ensure regionCount is less than numDLSRegions */
@@ -1794,14 +1934,14 @@ static EAS_RESULT Parse_rgn (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_I
     /* must have a rgnh chunk to be useful */
     if (!rgnhPos)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "DLS rgn chunk has no rgnh chunk\n"); */ }
+        EAS_Report(_EAS_SEVERITY_ERROR, "DLS rgn chunk has no rgnh chunk\n");
         return EAS_ERROR_UNRECOGNIZED_FORMAT;
     }
 
     /* must have a wlnk chunk to be useful */
     if (!wlnkPos)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_ERROR, "DLS rgn chunk has no wlnk chunk\n"); */ }
+        EAS_Report(_EAS_SEVERITY_ERROR, "DLS rgn chunk has no wlnk chunk\n");
         return EAS_ERROR_UNRECOGNIZED_FORMAT;
     }
 
@@ -1866,7 +2006,7 @@ static EAS_RESULT Parse_rgn (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_I
         {
             EAS_U32 sampleLen = pDLSData->pDLS->pDLSSampleLen[waveIndex];
             if (sampleLen < sizeof(EAS_SAMPLE)
-                || (pWsmp->loopStart + pWsmp->loopLength) * sizeof(EAS_SAMPLE) > sampleLen - sizeof(EAS_SAMPLE))
+                || (pWsmp->loopStart + pWsmp->loopLength) * sizeof(EAS_SAMPLE) > sampleLen)
             {
                 return EAS_FAILURE;
             }
@@ -1919,12 +2059,12 @@ static EAS_RESULT Parse_rgnh (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, S_DL
     /* check the range */
     if (lowKey > 127)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_WARNING, "DLS rgnh: Low key out of range [%u]\n", lowKey); */ }
+        EAS_Report(_EAS_SEVERITY_WARNING, "DLS rgnh: Low key out of range [%u]\n", lowKey);
         lowKey = 127;
     }
     if (highKey > 127)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_WARNING, "DLS rgnh: High key out of range [%u]\n", lowKey); */ }
+        EAS_Report(_EAS_SEVERITY_WARNING, "DLS rgnh: High key out of range [%u]\n", lowKey);
         highKey = 127;
     }
 
@@ -1937,12 +2077,12 @@ static EAS_RESULT Parse_rgnh (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, S_DL
     /* check the range */
     if (lowVel > 127)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_WARNING, "DLS rgnh: Low velocity out of range [%u]\n", lowVel); */ }
+        EAS_Report(_EAS_SEVERITY_WARNING, "DLS rgnh: Low velocity out of range [%u]\n", lowVel);
         lowVel = 127;
     }
     if (highVel > 127)
     {
-        { /* dpp: EAS_ReportEx(_EAS_SEVERITY_WARNING, "DLS rgnh: High velocity out of range [%u]\n", highVel); */ }
+        EAS_Report(_EAS_SEVERITY_WARNING, "DLS rgnh: High velocity out of range [%u]\n", highVel);
         highVel = 127;
     }
 
@@ -2121,7 +2261,7 @@ static EAS_RESULT Parse_art (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, S_DLS
             }
         }
         if (i == PARAM_TABLE_SIZE)
-            { /* dpp: EAS_ReportEx(_EAS_SEVERITY_WARNING, "WARN: Unsupported parameter in DLS file\n"); */ }
+            EAS_Report(_EAS_SEVERITY_WARNING, "WARN: Unsupported parameter in DLS file\n");
     }
 
     return EAS_SUCCESS;
@@ -2199,6 +2339,7 @@ static EAS_RESULT PushcdlStack (EAS_U32 *pStack, EAS_INT *pStackPtr, EAS_U32 val
 
     /* stack overflow, return an error */
     if (*pStackPtr >= (CDL_STACK_SIZE - 1)) {
+        EAS_Report(_EAS_SEVERITY_ERROR, "DLS cdl stack overflow\n");
         ALOGE("b/34031018, stackPtr(%d)", *pStackPtr);
         android_errorWriteLog(0x534e4554, "34031018");
         return EAS_ERROR_FILE_FORMAT;
@@ -2424,7 +2565,7 @@ static EAS_RESULT Parse_cdl (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 size, EAS_
             x = QueryGUID(&dlsid, &y);
         }
         else
-            { /* dpp: EAS_ReportEx(_EAS_SEVERITY_WARNING, "Unsupported opcode %d in DLS file\n", opcode); */ }
+            EAS_Report(_EAS_SEVERITY_WARNING, "Unsupported opcode %d in DLS file\n", opcode);
 
         /* push the result on the stack */
         if ((result = PushcdlStack(stack, &stackPtr, x)) != EAS_SUCCESS)
