@@ -845,6 +845,7 @@ static EAS_RESULT SMF_ParseMetaEvent (S_EAS_DATA *pEASData, S_SMF_DATA *pSMFData
     /* prevent a large unsigned length from being treated as a negative length */
     if ((EAS_I32) len < 0) {
         /* note that EAS_I32 is a long, which can be 64-bits on some computers */
+        EAS_Report(_EAS_SEVERITY_ERROR, "%s() negative len = %ld\n", __func__, (long) len);
         ALOGE("%s() negative len = %ld", __func__, (long) len);
         android_errorWriteLog(0x534e4554, "68953854");
         return EAS_ERROR_FILE_FORMAT;
@@ -852,6 +853,7 @@ static EAS_RESULT SMF_ParseMetaEvent (S_EAS_DATA *pEASData, S_SMF_DATA *pSMFData
     /* prevent numeric overflow caused by a very large len, assume pos > 0 */
     const EAS_I32 EAS_I32_MAX = 0x7FFFFFFF;
     if ((EAS_I32) len > (EAS_I32_MAX - pos)) {
+        EAS_Report(_EAS_SEVERITY_ERROR, "%s() too large len = %ld\n", __func__, (long) len);
         ALOGE("%s() too large len = %ld", __func__, (long) len);
         android_errorWriteLog(0x534e4554, "68953854");
         return EAS_ERROR_FILE_FORMAT;
