@@ -32,6 +32,7 @@
  * includes
  *------------------------------------
 */
+#include "eas_report.h"
 #include "log/log.h"
 #include <cutils/log.h>
 
@@ -96,10 +97,12 @@ void WT_VoiceGain (S_WT_VOICE *pWTVoice, S_WT_INT_FRAME *pWTIntFrame)
     /* initialize some local variables */
     numSamples = pWTIntFrame->numSamples;
     if (numSamples <= 0) {
+        EAS_Report(_EAS_SEVERITY_ERROR, "%s: numSamples <= 0\n", __func__);
         ALOGE("b/26366256");
         android_errorWriteLog(0x534e4554, "26366256");
         return;
     } else if (numSamples > BUFFER_SIZE_IN_MONO_SAMPLES) {
+        EAS_Report(_EAS_SEVERITY_ERROR, "%s: numSamples %ld > %d BUFFER_SIZE_IN_MONO_SAMPLES\n", __func__, numSamples, BUFFER_SIZE_IN_MONO_SAMPLES);
         ALOGE("b/317780080 clip numSamples %ld -> %d", numSamples, BUFFER_SIZE_IN_MONO_SAMPLES);
         android_errorWriteLog(0x534e4554, "317780080");
         numSamples = BUFFER_SIZE_IN_MONO_SAMPLES;
@@ -197,10 +200,12 @@ void WT_Interpolate (S_WT_VOICE *pWTVoice, S_WT_INT_FRAME *pWTIntFrame)
     /* initialize some local variables */
     numSamples = pWTIntFrame->numSamples;
     if (numSamples <= 0) {
+        EAS_Report(_EAS_SEVERITY_ERROR, "%s: numSamples <= 0\n", __func__);
         ALOGE("b/26366256");
         android_errorWriteLog(0x534e4554, "26366256");
         return;
     } else if (numSamples > BUFFER_SIZE_IN_MONO_SAMPLES) {
+        EAS_Report(_EAS_SEVERITY_ERROR, "%s: numSamples %ld > %d BUFFER_SIZE_IN_MONO_SAMPLES\n", __func__, numSamples, BUFFER_SIZE_IN_MONO_SAMPLES);
         ALOGE("b/317780080 clip numSamples %ld -> %d", numSamples, BUFFER_SIZE_IN_MONO_SAMPLES);
         android_errorWriteLog(0x534e4554, "317780080");
         numSamples = BUFFER_SIZE_IN_MONO_SAMPLES;
@@ -302,10 +307,12 @@ void WT_InterpolateNoLoop (S_WT_VOICE *pWTVoice, S_WT_INT_FRAME *pWTIntFrame)
     /* initialize some local variables */
     numSamples = pWTIntFrame->numSamples;
     if (numSamples <= 0) {
+        EAS_Report(_EAS_SEVERITY_ERROR, "%s: numSamples <= 0\n", __func__);
         ALOGE("b/26366256");
         android_errorWriteLog(0x534e4554, "26366256");
         return;
     } else if (numSamples > BUFFER_SIZE_IN_MONO_SAMPLES) {
+        EAS_Report(_EAS_SEVERITY_ERROR, "%s: numSamples %ld > %d BUFFER_SIZE_IN_MONO_SAMPLES\n", __func__, numSamples, BUFFER_SIZE_IN_MONO_SAMPLES);
         ALOGE("b/317780080 clip numSamples %ld -> %d", numSamples, BUFFER_SIZE_IN_MONO_SAMPLES);
         android_errorWriteLog(0x534e4554, "317780080");
         numSamples = BUFFER_SIZE_IN_MONO_SAMPLES;
@@ -406,10 +413,12 @@ void WT_VoiceFilter (S_FILTER_CONTROL *pFilter, S_WT_INT_FRAME *pWTIntFrame)
     /* initialize some local variables */
     numSamples = pWTIntFrame->numSamples;
     if (numSamples <= 0) {
+        EAS_Report(_EAS_SEVERITY_ERROR, "%s: numSamples <= 0\n", __func__);
         ALOGE("b/26366256");
         android_errorWriteLog(0x534e4554, "26366256");
         return;
     } else if (numSamples > BUFFER_SIZE_IN_MONO_SAMPLES) {
+        EAS_Report(_EAS_SEVERITY_ERROR, "%s: numSamples %ld > %d BUFFER_SIZE_IN_MONO_SAMPLES\n", __func__, numSamples, BUFFER_SIZE_IN_MONO_SAMPLES);
         ALOGE("b/317780080 clip numSamples %ld -> %d", numSamples, BUFFER_SIZE_IN_MONO_SAMPLES);
         android_errorWriteLog(0x534e4554, "317780080");
         numSamples = BUFFER_SIZE_IN_MONO_SAMPLES;
@@ -478,10 +487,12 @@ void WT_VoiceFilter (S_FILTER_CONTROL *pFilter, S_WT_INT_FRAME *pWTIntFrame)
     /* initialize some local variables */
     numSamples = pWTIntFrame->numSamples;
     if (numSamples <= 0) {
+        EAS_Report(_EAS_SEVERITY_ERROR, "%s: numSamples <= 0\n", __func__);
         ALOGE("b/26366256");
         android_errorWriteLog(0x534e4554, "26366256");
         return;
     } else if (numSamples > BUFFER_SIZE_IN_MONO_SAMPLES) {
+        EAS_Report(_EAS_SEVERITY_ERROR, "%s: numSamples %ld > %d BUFFER_SIZE_IN_MONO_SAMPLES\n", __func__, numSamples, BUFFER_SIZE_IN_MONO_SAMPLES);
         ALOGE("b/317780080 clip numSamples %ld -> %d", numSamples, BUFFER_SIZE_IN_MONO_SAMPLES);
         android_errorWriteLog(0x534e4554, "317780080");
         numSamples = BUFFER_SIZE_IN_MONO_SAMPLES;
@@ -630,10 +641,12 @@ void WT_InterpolateMono (S_WT_VOICE *pWTVoice, S_WT_INT_FRAME *pWTIntFrame)
 
     numSamples = pWTIntFrame->numSamples;
     if (numSamples <= 0) {
+        EAS_Report(_EAS_SEVERITY_ERROR, "%s: numSamples <= 0\n", __func__);
         ALOGE("b/26366256");
         android_errorWriteLog(0x534e4554, "26366256");
         return;
     } else if (numSamples > BUFFER_SIZE_IN_MONO_SAMPLES) {
+        EAS_Report(_EAS_SEVERITY_ERROR, "%s: numSamples %ld > %d BUFFER_SIZE_IN_MONO_SAMPLES\n", __func__, numSamples, BUFFER_SIZE_IN_MONO_SAMPLES);
         ALOGE("b/317780080 clip numSamples %ld -> %d", numSamples, BUFFER_SIZE_IN_MONO_SAMPLES);
         android_errorWriteLog(0x534e4554, "317780080");
         numSamples = BUFFER_SIZE_IN_MONO_SAMPLES;
