@@ -494,10 +494,12 @@ EAS_BOOL WT_CheckSampleEnd (S_WT_VOICE *pWTVoice, S_WT_INT_FRAME *pWTIntFrame, E
             pWTIntFrame->numSamples = numSamples;
         }
         if (pWTIntFrame->numSamples < 0) {
+            EAS_Report(_EAS_SEVERITY_ERROR, "%s: numSamples <= 0\n", __func__);
             ALOGE("b/26366256");
             android_errorWriteLog(0x534e4554, "26366256");
             pWTIntFrame->numSamples = 0;
         } else if (pWTIntFrame->numSamples > BUFFER_SIZE_IN_MONO_SAMPLES) {
+            EAS_Report(_EAS_SEVERITY_ERROR, "%s: numSamples %ld > %d BUFFER_SIZE_IN_MONO_SAMPLES\n", __func__, pWTIntFrame->numSamples, BUFFER_SIZE_IN_MONO_SAMPLES);
             ALOGE("b/317780080 clip numSamples %ld -> %d",
                   pWTIntFrame->numSamples, BUFFER_SIZE_IN_MONO_SAMPLES);
             android_errorWriteLog(0x534e4554, "317780080");
